/*
 * $Id: cobalt-systype.h,v 1.6 2001/10/03 23:43:10 thockin Exp $
 * cobalt-systype.h : figure out what Cobalt system we are on
 *
 * Copyright 2000 Cobalt Networks, Inc.
 * Copyright 2001 Sun Microsystems, Inc.
 */
#ifndef COBALT_SYSTYPE_H
#define COBALT_SYSTYPE_H

#include <linux/cobalt.h>

typedef enum {
	COBT_UNINITIALIZED,
	COBT_UNKNOWN,
	COBT_PACIFICA,
	COBT_CARMEL,
	COBT_MONTEREY,
	COBT_ALPINE,
} cobt_sys_t;

extern cobt_sys_t cobt_type;
extern cobt_sys_t cobalt_systype_probe(void);

/* 
 * one test for each major board-type 
 * COBT_SUPPORT_* from <linux/cobalt.h> 
 */

/* pacifica is the RaQ 3 and RaQ 4 platform */
static inline int
cobt_is_pacifica(void)
{
	if (!COBT_SUPPORT_GEN_III) {
		return 0;
	}
	if (cobt_type == COBT_UNINITIALIZED) {
		cobalt_systype_probe();
	}
	return (cobt_type == COBT_PACIFICA);
}

/* carmel is the Qube 3 platform */
static inline int
cobt_is_carmel(void)
{
	if (!COBT_SUPPORT_GEN_III) {
		return 0;
	}
	if (cobt_type == COBT_UNINITIALIZED) {
		cobalt_systype_probe();
	}
	return (cobt_type == COBT_CARMEL);
}

/* monterey is the RaQ XTR platform */
static inline int
cobt_is_monterey(void)
{
	if (!COBT_SUPPORT_GEN_V) {
		return 0;
	}
	if (cobt_type == COBT_UNINITIALIZED) {
		cobalt_systype_probe();
	}
	return (cobt_type == COBT_MONTEREY);
}

static inline int
cobt_is_alpine(void)
{
	if (!COBT_SUPPORT_GEN_V) {
		return 0;
	}
	if (cobt_type == COBT_UNINITIALIZED) {
		cobalt_systype_probe();
	}
	return (cobt_type == COBT_ALPINE);
}

/* one for each major generation */
#define cobt_is_3k()	 (cobt_is_pacifica() || cobt_is_carmel())
#define cobt_is_5k()	 (cobt_is_monterey() || cobt_is_alpine())

#endif
