/*
  File: linux/extattr.h

  Extended attributes handling.

  Copyright (C) 2001 by Andreas Gruenbacher <a.gruenbacher@computer.org>
  Copyright (C) 2001 SGI - Silicon Graphics, Inc <linux-xfs@oss.sgi.com>
*/
#ifndef _LINUX_EXTATTR_H
#define _LINUX_EXTATTR_H

/* Operations */
#define EA_SET		1	/* set the value, create attr where necessary */
#define EA_CREATE	2	/* set the value, fail if attr already exists */
#define EA_REPLACE	3	/* set the value, fail if attr does not exist */
#define EA_REMOVE	4	/* remove the named attribute entirely */
#define EA_GET		5	/* get the value for named attribute */
#define EA_GETSIZE	6	/* size of value for named attribute */
#define EA_LIST		7	/* get the list of attribute names */
#define EA_LISTSIZE	8	/* size of list of attribute names */

/* Additional flags to operations */
#define EA_FLAG_USER	0x0001	/* copying to/from userspace (for kernel use) */

#define EAMASK		0xFFFF
#define EASHIFT		16
#define EACMD(op,flags)	(((flags) << EASHIFT) | (op))

#ifndef __KERNEL__
# /* nodep */ include <features.h>
__BEGIN_DECLS
extern ssize_t  extattr (const char *__path, int __cmd,
			 char *__name, void *__value, size_t __size) __THROW;
extern ssize_t lextattr (const char *__path, int __cmd,
			 char *__name, void *__value, size_t __size) __THROW;
extern ssize_t fextattr (int __fd, int __cmd,
			 char *__name, void *__value, size_t __size) __THROW;
__END_DECLS
#endif
#endif	/* _LINUX_EXTATTR_H */
